/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.padre.test;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.util.List;
import java.util.Vector;

import org.bbaw.pdr.padre.PadreConfiguration;
import org.bbaw.pdr.padre.PadreContains;
import org.bbaw.pdr.padre.client.PadreClient;
import org.bbaw.pdr.padre.request.PadreID;
import org.bbaw.pdr.padre.request.PadreObject;
import org.bbaw.pdr.padre.request.PadreObjectException;
import org.bbaw.pdr.utils.Identifier;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;

/**
*
* @author Fabian Körner
*/
public class TestPadreContains
{

	private static final TestConfiguration CONFIGURATION = new TestConfigurationFromFile();

	private PadreClient _padreClient;

	/**
	 * @throws Exception Exception.
	 */
	@Before
	public final void setUp() throws Exception
	{
		PadreConfiguration.getInstance().setCredentials(CONFIGURATION.getUri(), CONFIGURATION.getUsername(), CONFIGURATION.getPassword());
		_padreClient = PadreConfiguration.getInstance().getPadreClient();

		_padreClient.createStore("31e");
		List<PadreObject> testObjects = new Vector<PadreObject>();
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000001")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000002")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000003")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.00000001f")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000020")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000021")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000022")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000023")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000024")));
		testObjects.add(TestPadreContains.createTestObject(new PadreID("pdrAo.001.31e.000000025")));
		_padreClient.write(testObjects);

	}

	/**
	 * @throws Exception Exception.
	 */
	@After
	public final void tearDown() throws Exception
	{
		_padreClient.deleteStore("31e");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testContainsIdentifierTrue() throws Exception
	{
		Identifier identifier = new Identifier("pdrAo.001.798.000000001");
		Boolean actual = new PadreContains(identifier).execute();
		assertTrue(actual.booleanValue());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testContainsIdentifierFalse() throws Exception
	{
		Identifier identifier = new Identifier("pdrAo.001.798.000002001");
		Boolean actual = new PadreContains(identifier).execute();
		assertFalse(actual.booleanValue());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testContainsStringTrue() throws Exception
	{
		Boolean actual = new PadreContains("pdrAo.001.798.000000003").execute();
		assertTrue(actual.booleanValue());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testContainsStringFalse() throws Exception
	{
		Boolean actual = new PadreContains("pdrAo.001.798.000000007").execute();
		assertFalse(actual.booleanValue());
	}

	private static PadreObject createTestObject(final PadreID padreID) throws PadreObjectException
	{
		return new PadreObject(padreID, "dGVzdA==", "2b200a668f372eb923099cbdb250d0aa340de0163088de1e23482b1a4c50ae9b");
	}

}
