/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import java.net.URI;

import org.apache.solr.client.solrj.SolrServer;
import org.apache.solr.client.solrj.impl.HttpSolrServer;

/**
 * Contains information about access to our Solr index via Solrj.
 * @author Fabian Körner
 */
public final class SolrConfiguration
{

	private URI _baseURI = null;
	private SolrServer _server = null;

	private static final SolrConfiguration INSTANCE = new SolrConfiguration();

	private SolrConfiguration()
	{
	}

	/**
	 * Singleton: return unique instance.
	 * @return Unique instance.
	 */
	public static SolrConfiguration getInstance()
	{
		return INSTANCE;
	}

	/**
	 * Configure base URI of Solr server.
	 * @param baseURI Base URI of Solr server.
	 */
	public void setBaseURI(final URI baseURI)
	{
		_baseURI = baseURI;
		_server = new HttpSolrServer(_baseURI.toString());
	}

	/**
	 * Provides the server object for interactions with Solr.
	 * @return Solr server.
	 */
	public SolrServer getSolrServer()
	{
		return _server;
	}

	protected URI getBaseUri()
	{
		return _baseURI;
	}
}
