/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;


/**
 * Implements Apache Solr's delete command.
 * @author Fabian Körner
 */
public final class SolrDelete extends AbstractSolrCommand<Object>
{

	private String _query;

	/**
	 * Constructor for deletion by provided Solr query string.
	 * @param query Solr query string.
	 * @throws SolrCommandException Could not successfully create Solr command.
	 */
	public SolrDelete(final String query) throws SolrCommandException
	{
		super();
		_query = query;
	}

	/**
	 * @see org.bbaw.pdr.solr.AbstractSolrCommand#execute()
	 * @return Null.
	 * @throws SolrCommandException Could not successfully execute Solr command.
	 */
	@Override
	public Object execute() throws SolrCommandException
	{
		try
		{
			super.getSolrServer().deleteByQuery(_query);
		}
		catch (Exception cause)
		{
			throw new SolrCommandException(cause);
		}
		return null;
	}
}
