/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr.test;

import static org.junit.Assert.assertEquals;

import org.apache.commons.codec.digest.DigestUtils;
import org.apache.solr.common.SolrInputDocument;
import org.bbaw.pdr.solr.SolrInputDocumentFactory;
import org.bbaw.pdr.utils.PDRObject;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestSolrInput
{
	//TODO full revision!
	private static String _aspect1 =
		"<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
		+ "xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.002.000000004\">"
		+ "<record><revision ref=\"0\" timestamp=\"2011-04-05T17:46:49\" authority=\"pdrUo.001.002.000000001\"></revision></record>"
		+ "<timeDim><timeStm type=\"periodOfLife\"><time accuracy=\"exact\" type=\"from\">1900-01-01</time><time accuracy=\"imprecise\" "
		+ "type=\"when\">1901-02-03</time></timeStm><timeStm type=\"timeless\" /></timeDim><spatialDim><spatialStm type=\"defined\">"
		+ "<place type=\"type_halt\">Dingens</place></spatialStm><spatialStm type=\"defined\"><place type=\"lgkjh\" subtype=\"rga\" "
		+ "key=\"30ru\">hier_nicht_da</place><place type=\"type_halt\" subtype=\"untertyp\">Dingens</place></spatialStm></spatialDim>"
		+ "<relationDim><relationStm subject=\"pdrAo.001.002.000000004\"><relation object=\"pdrPo.001.002.000000001\" "
		+ "provider=\"ARCHIV_ALTMITGLIEDER\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm "
		+ "provider=\"ARCHIV_ALTMITGLIEDER\">disciplines</semanticStm></semanticDim><notification><name type=\"science\">Physik</name>, "
		+ "<name type=\"science\">Mikroskopie</name>,<lb /><name type=\"science\">Optik<lb/></name>, <name type=\"science\"> Photographie</name>"
		+ "</notification><validation><validationStm authority=\"pdrUo.001.002.000000001\"><reference quality=\"certain\" "
		+ "internal=\"http://www.bbaw.de/die-akademie/akademiegeschichte/mitglieder-historisch/chronologische-sortierung?altmitglied_id=2 "
		+ "(04.04.2011)\">pdrRo.001.002.000000001</reference><reference quality=\"certain\">pdrRo.001.002.000000002</reference><interpretation>"
		+ "</interpretation></validationStm></validation></aspect>";
	private static String _person1 =
		"<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
		+ "xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.002.000000009\"><record>"
		+ "<revision ref=\"0\" timestamp=\"2011-04-07T11:38:15\" authority=\"pdrUo.001.002.000000001\"/></record><identifiers><identifier "
		+ "provider=\"ARCHIV_ALTMITGLIEDER\" quality=\"certain\" authority=\"pdrUo.001.002.000000001\">16</identifier><identifier provider=\"TEST\" "
		+ "quality=\"probable\" authority=\"pdrUo.001.002.000000001\">128461</identifier></identifiers><concurrences><concurrence "
		+ "person=\"pdrPo.001.002.000000001\"><validationStm authority=\"pdrUo.001.002.000000001\"><reference quality=\"unsure\" "
		+ "authority=\"pdrUo.001.002.000000001\">pdrRo.001.002.000000001</reference><interpretation>Steht da so.</interpretation></validationStm>"
		+ "</concurrence><concurrence person=\"pdrPo.023.077.000000876\"><validationStm authority=\"pdrUo.001.002.000000001\"><reference quality=\"unsure\" "
		+ "authority=\"pdrUo.001.002.000000001\">pdrRo.001.002.000000001</reference><interpretation>Steht da halt so.</interpretation></validationStm>"
		+ "</concurrence></concurrences></person>";
	private static String _reference1 =
		"<mods xmlns=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
		+ "xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.002.000000003\">"
		+ "<titleInfo><title>Automatische Erkennung von Identitäten im Altmitglieder-Verzeichnis der BBAW</title></titleInfo><name>"
		+ "<namePart type=\"family\">Roeder</namePart><namePart type=\"given\">Torsten</namePart>"
		+ "<affiliation>DFG-Projekt &quot;Personendaten-Repositorium&quot;</affiliation><role><roleTerm authority=\"marcrelator\" "
		+ "type=\"code\">prg</roleTerm></role></name><genre authority=\"PDR\">Skript</genre><originInfo><copyrightDate encoding=\"iso8601\">"
		+ "2011</copyrightDate><publisher>Berlin-Brandenburgische Akademie der Wissenschaften</publisher><place><placeTerm type=\"text\">Berlin</placeTerm>"
		+ "</place></originInfo><location><url>http://pdrdev.bbaw.de/transform/altmitglieder</url></location><recordInfo><recordCreationDate "
		+ "encoding=\"iso8601\">2011-03-31T11:55:12</recordCreationDate><recordContentSource authority=\"marcrelator\">pdrUo.001.002.000000001"
		+ "</recordContentSource></recordInfo></mods>";
	private static String _user1 =
		"<user xmlns=\"http://pdr.bbaw.de/namespaces/uodl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" "
		+ "xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/uodl/ http://pdr.bbaw.de/schema/uodl.xsd\" id=\"pdrUo.001.002.000000009\"><record>"
		+ "<revision authority=\"pdrUo.001.002.000000001\" ref=\"0\" timestamp=\"2011-04-07T15:41:52\"></revision></record><authentication "
		+ "password=\"dummy_password\" username=\"dummy_username\"><roles><role>dummy_role1</role><role>dummy_role2</role></roles></authentication></user>";

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateSolrInputDocumentFromAspect() throws Exception
	{
		PDRObject pdrObject = new PDRObject(_aspect1);
		SolrInputDocument inputDocument = SolrInputDocumentFactory.createSolrInputDocument(pdrObject);

		String expected = "SolrInputDocument[{"
			+ "id=id(1.0)={pdrAo.001.002.000000004}, "
			+ "id.type=id.type(1.0)={pdrAo}, "
			+ "id.instance=id.instance(1.0)={1}, "
			+ "id.project=id.project(1.0)={2}, "
			+ "id.object=id.object(1.0)={4}, "
			+ "revision.timestamp=revision.timestamp(1.0)={2011-04-05T17:46:49Z}, "
			+ "revision.authority=revision.authority(1.0)={pdrUo.001.002.000000001}, "
			+ "crevision=crevision(1.0)={2011-04-05T17:46:49Z|pdrUo.001.002.000000001}, "
			+ "time=time(1.0)={[1900-01-01T00:00:00Z, 1901-02-03T00:00:00Z]}, "
			+ "time.type=time.type(1.0)={[from, when]}, "
			+ "ctime=ctime(1.0)={[1900-01-01|from, 1901-02-03|when]}, "
			+ "place=place(1.0)={[Dingens, hier_nicht_da, Dingens]}, "
			+ "place.type=place.type(1.0)={[type_halt, lgkjh, type_halt]}, "
			+ "cplace=cplace(1.0)={[Dingens|type_halt|null|null, hier_nicht_da|lgkjh|rga|30ru, Dingens|type_halt|untertyp|null]}, "
			+ "place.subtype=place.subtype(1.0)={[rga, untertyp]}, "
			+ "place.key=place.key(1.0)={30ru}, "
			+ "relation=relation(1.0)={aspect_of}, "
			+ "relation.subject=relation.subject(1.0)={pdrAo.001.002.000000004}, "
			+ "relation.object=relation.object(1.0)={pdrPo.001.002.000000001}, "
			+ "relation.provider=relation.provider(1.0)={ARCHIV_ALTMITGLIEDER}, "
			+ "crelation=crelation(1.0)={pdrAo.001.002.000000004|aspect_of|pdrPo.001.002.000000001|ARCHIV_ALTMITGLIEDER|null|null}, "
			+ "semantic=semantic(1.0)={disciplines}, "
			+ "semantic.provider=semantic.provider(1.0)={ARCHIV_ALTMITGLIEDER}, "
			+ "csemantic=csemantic(1.0)={disciplines|ARCHIV_ALTMITGLIEDER}, "
			+ "notification=notification(1.0)={Physik, Mikroskopie,\nOptik\n,  Photographie}, "
			+ "notification.name=notification.name(1.0)={[Physik, Mikroskopie, Optik\n,  Photographie]}, "
			+ "notification.name.type=notification.name.type(1.0)={[science, science, science, science]}, "
			+ "notification.cname=notification.cname(1.0)={[Physik|science|null|null|null|null, Mikroskopie|science|null|null|null|null, "
			+ "Optik\n|science|null|null|null|null,  Photographie|science|null|null|null|null]}, "
			+ "validation.reference=validation.reference(1.0)={[pdrRo.001.002.000000001, pdrRo.001.002.000000002]}"
			+ "}]";
		String actual = inputDocument.toString();
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateSolrInputDocumentFromPerson() throws Exception
	{
		PDRObject pdrObject = new PDRObject(_person1);
		SolrInputDocument inputDocument = SolrInputDocumentFactory.createSolrInputDocument(pdrObject);

		String expected = "SolrInputDocument[{"
			+ "id=id(1.0)={pdrPo.001.002.000000009}, "
			+ "id.type=id.type(1.0)={pdrPo}, "
			+ "id.instance=id.instance(1.0)={1}, "
			+ "id.project=id.project(1.0)={2}, "
			+ "id.object=id.object(1.0)={9}, "
			+ "revision.timestamp=revision.timestamp(1.0)={2011-04-07T11:38:15Z}, "
			+ "revision.authority=revision.authority(1.0)={pdrUo.001.002.000000001}, "
			+ "crevision=crevision(1.0)={2011-04-07T11:38:15Z|pdrUo.001.002.000000001}, "
			+ "person.identifier.provider=person.identifier.provider(1.0)={[ARCHIV_ALTMITGLIEDER, TEST]}, "
			+ "person.identifier=person.identifier(1.0)={[16, 128461]}, "
			+ "person.cidentifier=person.cidentifier(1.0)={[16|ARCHIV_ALTMITGLIEDER, 128461|TEST]}, "
			+ "person.concurrence=person.concurrence(1.0)={[pdrPo.001.002.000000001, pdrPo.023.077.000000876]}"
			+ "}]";

		String actual = inputDocument.toString();
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateSolrInputDocumentFromReference() throws Exception
	{
		PDRObject pdrObject = new PDRObject(_reference1);
		SolrInputDocument inputDocument = SolrInputDocumentFactory.createSolrInputDocument(pdrObject);

		String expected = "SolrInputDocument[{"
			+ "id=id(1.0)={pdrRo.001.002.000000003}, "
			+ "id.type=id.type(1.0)={pdrRo}, "
			+ "id.instance=id.instance(1.0)={1}, "
			+ "id.project=id.project(1.0)={2}, "
			+ "id.object=id.object(1.0)={3}, "
			+ "revision.timestamp=revision.timestamp(1.0)={2011-03-31T11:55:12Z}, "
			+ "revision.authority=revision.authority(1.0)={pdrUo.001.002.000000001}, "
			+ "crevision=crevision(1.0)={2011-03-31T11:55:12Z|pdrUo.001.002.000000001}, "
			+ "reference.title=reference.title(1.0)={Automatische Erkennung von Identitäten im Altmitglieder-Verzeichnis der BBAW}, "
			+ "reference.name=reference.name(1.0)={[Roeder, Torsten]}"
			+ "}]";

		String actual = inputDocument.toString();
		assertEquals(expected, actual);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCreateSolrInputDocumentFromUser() throws Exception
	{
		PDRObject pdrObject = new PDRObject(_user1);
		SolrInputDocument inputDocument = SolrInputDocumentFactory.createSolrInputDocument(pdrObject);

		String expected = "SolrInputDocument[{"
			+ "id=id(1.0)={pdrUo.001.002.000000009}, "
			+ "id.type=id.type(1.0)={pdrUo}, "
			+ "id.instance=id.instance(1.0)={1}, "
			+ "id.project=id.project(1.0)={2}, "
			+ "id.object=id.object(1.0)={9}, "
			+ "revision.timestamp=revision.timestamp(1.0)={2011-04-07T15:41:52Z}, "
			+ "revision.authority=revision.authority(1.0)={pdrUo.001.002.000000001}, "
			+ "crevision=crevision(1.0)={2011-04-07T15:41:52Z|pdrUo.001.002.000000001}, "
			+ "user.username=user.username(1.0)={dummy_username}, "
			+ "user.password=user.password(1.0)={" + DigestUtils.md5Hex("dummy_password") + "}, "
			+ "user.role=user.role(1.0)={[dummy_role1, dummy_role2]}"
			+ "}]";

		String actual = inputDocument.toString();
		assertEquals(expected, actual);
	}
}
