/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.utils.test;

import static org.junit.Assert.assertEquals;

import java.util.Date;
import java.util.List;

import org.bbaw.pdr.utils.PDRObject;
import org.bbaw.pdr.utils.ValidationException;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestPDRObject
{

	private static final String VALID_PDRAO_1_43_4 = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-ins"
			+ "tance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.043.000000004\"><record><re"
			+ "vision ref=\"0\" timestamp=\"2014-01-21T17:21:23\" authority=\"pdrUo.001.043.000000010\"/></record><timeDim><timeStm type=\"undefined\"/></timeD"
			+ "im><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.043.000000004\"><relation object=\"pdr"
			+ "Po.001.043.000000001\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">career</s"
			+ "emanticStm></semanticDim><notification>war<name type=\"occupation\" subtype=\"science\" ana=\"pdrPo.001.043.000000001\">o. Prof.</name>für<name "
			+ "type=\"science\" subtype=\"subject\" ana=\"pdrPo.001.043.000000001\">Mathematik</name>an<orgName type=\"academic\" ana=\"pdrPo.001.043.000000001"
			+ "\">U Frankfurt</orgName>von<date type=\"residence\" subtype=\"temporary\" ana=\"pdrPo.001.043.000000001\" from=\"1915\" to=\"1921\">1915 - 1921<"
			+ "/date></notification><validation><validationStm authority=\"pdrUo.001.043.000000010\"><reference quality=\"certain\">pdrRo.001.043.000000001</re"
			+ "ference><interpretation/></validationStm></validation></aspect>";

	private static final String VALID_PDRAO_1_512_1 = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-in"
			+ "stance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.512.000000001\"><record><r"
			+ "evision ref=\"0\" timestamp=\"2014-02-12T09:59:50\" authority=\"pdrUo.001.512.000000001\"/></record><timeDim><timeStm type=\"undefined\"/></time"
			+ "Dim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.512.000000001\"><relation object=\"pd"
			+ "rPo.001.512.000000001\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">NormName"
			+ "_DE</semanticStm></semanticDim><notification><persName type=\"forename\" ana=\"pdrPo.001.512.000000001\">Maxi</persName> <persName type=\"surnam"
			+ "e\" ana=\"pdrPo.001.512.000000001\">Manna</persName></notification><validation><validationStm authority=\"pdrUo.001.512.000000001\"><reference q"
			+ "uality=\"certain\">pdrRo.001.002.100000001</reference><interpretation/></validationStm></validation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_DATE_Y = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2001/"
			+ "XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.000000005"
			+ "\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"undefi"
			+ "ned\"/></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.042.000000005\"><relatio"
			+ "n object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2"
			+ ".0\">biographicalData</semanticStm></semanticDim><notification>Entry in the order:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" when=\"17"
			+ "13\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">Krakow</placeName></notification><validation><validationStm autho"
			+ "rity=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.000000002</reference><interpretation/></validationStm></validation"
			+ "></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_DATE_YM = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2001"
			+ "/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.000000005"
			+ "\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"undefi"
			+ "ned\"/></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.042.000000005\"><relat"
			+ "ion object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR"
			+ "_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the order:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" from=\""
			+ "1713-07\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">Krakow</placeName></notification><validation><validationStm "
			+ "authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.000000002</reference><interpretation/></validationStm></valid"
			+ "ation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_DATE_YMD = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/200"
			+ "1/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.00000000"
			+ "5\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"undef"
			+ "ined\"/></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.042.000000005\"><relati"
			+ "on object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_"
			+ "2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the order:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" to=\"171"
			+ "3-12-12\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">Krakow</placeName></notification><validation><validationStm "
			+ "authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.000000002</reference><interpretation/></validationStm></valid"
			+ "ation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_DATE_YMDHM = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2"
			+ "001/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.000000"
			+ "005\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"und"
			+ "efined\"/></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.042.000000005\"><rela"
			+ "tion object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PD"
			+ "R_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the order:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" notBef"
			+ "ore=\"1713-01-03T09:10\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">Krakow</placeName></notification><validation>"
			+ "<validationStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.000000002</reference><interpretation/></valida"
			+ "tionStm></validation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_DATE_YMDHMS = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/"
			+ "2001/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.00000"
			+ "0005\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"un"
			+ "defined\"/></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.042.000000005\"><rel"
			+ "ation object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"P"
			+ "DR_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the order:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" notAf"
			+ "ter=\"1713-10-10T12:10:23\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">Krakow</placeName></notification><validati"
			+ "on><validationStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.000000002</reference><interpretation/></val"
			+ "idationStm></validation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_TIME_Y = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2001/"
			+ "XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.000000005"
			+ "\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"define"
			+ "d\"><time accuracy=\"exact\" type=\"when\">1775</time></timeStm></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim>"
			+ "<relationStm subject=\"pdrAo.001.042.000000005\"><relation object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></relationStm"
			+ "></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the order:<date"
			+ " type=\"event\" ana=\"pdrPo.001.042.000000002\" when=\"1713\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">Krakow</"
			+ "placeName></notification><validation><validationStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.000000002"
			+ "</reference><interpretation/></validationStm></validation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_TIME_YM = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2001"
			+ "/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.000000005"
			+ "\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"define"
			+ "d\"><time accuracy=\"exact\" type=\"when\">1775-08</time></timeStm></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationD"
			+ "im><relationStm subject=\"pdrAo.001.042.000000005\"><relation object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></relation"
			+ "Stm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the order:<d"
			+ "ate type=\"event\" ana=\"pdrPo.001.042.000000002\" when=\"1713\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">Krako"
			+ "w</placeName></notification><validation><validationStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.000000"
			+ "002</reference><interpretation/></validationStm></validation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_TIME_YMD = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/200"
			+ "1/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.00000000"
			+ "5\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"defin"
			+ "ed\"><time accuracy=\"exact\" type=\"when\">1775-09-05</time></timeStm></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relat"
			+ "ionDim><relationStm subject=\"pdrAo.001.042.000000005\"><relation object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></rela"
			+ "tionStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the orde"
			+ "r:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" when=\"1713\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">K"
			+ "rakow</placeName></notification><validation><validationStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.00"
			+ "0000002</reference><interpretation/></validationStm></validation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_TIME_YMDHM = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2"
			+ "001/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.000000"
			+ "005\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"def"
			+ "ined\"><time accuracy=\"exact\" type=\"when\">1775-12-12T13:46</time></timeStm></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDi"
			+ "m><relationDim><relationStm subject=\"pdrAo.001.042.000000005\"><relation object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relatio"
			+ "n></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in "
			+ "the order:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" when=\"1713\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.00000"
			+ "0002\">Krakow</placeName></notification><validation><validationStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.00"
			+ "1.042.000000002</reference><interpretation/></validationStm></validation></aspect>";

	private static final String VALID_ASPECT_1_42_5_WITH_TIME_YMDHMS = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/"
			+ "2001/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.00000"
			+ "0005\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"de"
			+ "fined\"><time accuracy=\"exact\" type=\"when\">1775-09-02T17:28:49</time></timeStm></timeDim><spatialDim><spatialStm type=\"undefined\"/></spati"
			+ "alDim><relationDim><relationStm subject=\"pdrAo.001.042.000000005\"><relation object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</rel"
			+ "ation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry"
			+ " in the order:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" when=\"1713\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.0"
			+ "00000002\">Krakow</placeName></notification><validation><validationStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrR"
			+ "o.001.042.000000002</reference><interpretation/></validationStm></validation></aspect>";

	private static final String INVALID_PDRAO_1_512_1_ASPEKT = "<aspekt xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/2001/XML"
			+ "Schema-instance\" xsi:schemaLocation=\"h"
			+ "ttp://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.512.000000001\"><record><revision ref=\"0\" timestamp"
			+ "=\"2014-02-12T09:59:50\" authority=\"pdrUo.001.512.000000001\"/></record><timeDim><timeStm type=\"undefined\"/></timeDim><spatialDim><spatia"
			+ "lStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.512.000000001\"><relation object=\"pdrPo.001.512.0000000"
			+ "01\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">NormName_DE</semanticSt"
			+ "m></semanticDim><notification><persName type=\"forename\" ana=\"pdrPo.001.512.000000001\">Maxi</persName> <persName type=\"surname\" ana=\"p"
			+ "drPo.001.512.000000001\">Manna</persName></notification><validation><validationStm authority=\"pdrUo.001.512.000000001\"><reference quality="
			+ "\"certain\">pdrRo.001.002.100000001</reference><interpretation/></validationStm></validation></aspekt>";

	private static final String INVALID_PDRAO_1_512_1_EMPTY_REFERENCE = "<aspekt xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org"
			+ "/2001/XMLSchema-instance\" xsi:schemaLocation=\"htt"
			+ "p://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.512.000000001\"><record><revision ref=\"0\" timestamp="
			+ "\"2014-02-12T09:59:50\" authority=\"pdrUo.001.512.000000001\"/></record><timeDim><timeStm type=\"undefined\"/></timeDim><spatialDim><spatial"
			+ "Stm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.512.000000001\"><relation object=\"pdrPo.001.512.00000000"
			+ "1\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">NormName_DE</semanticStm"
			+ "></semanticDim><notification><persName type=\"forename\" ana=\"pdrPo.001.512.000000001\">Maxi</persName> <persName type=\"surname\" ana=\"pd"
			+ "rPo.001.512.000000001\">Manna</persName></notification><validation><validationStm authority=\"pdrUo.001.512.000000001\"><reference /><interp"
			+ "retation/></validationStm></validation></aspect>";

	private static final String INVALID_PDRAO_1_512_1_MISSING_AUTHORITY_ATTRIBUTE = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http:"
			+ "//www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"htt"
			+ "p://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.512.000000001\"><record><revision ref=\"0\" timestamp="
			+ "\"2014-02-12T09:59:50\" authority=\"pdrUo.001.512.000000001\"/></record><timeDim><timeStm type=\"undefined\"/></timeDim><spatialDim><spatial"
			+ "Stm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.512.000000001\"><relation object=\"pdrPo.001.512.00000000"
			+ "1\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">NormName_DE</semanticStm"
			+ "></semanticDim><notification><persName type=\"forename\" ana=\"pdrPo.001.512.000000001\">Maxi</persName> <persName type=\"surname\" ana=\"pd"
			+ "rPo.001.512.000000001\">Manna</persName></notification><validation><validationStm><reference quality=\"certain\">pdrRo.001.002.100000001</re"
			+ "ference><interpretation/></validationStm></validation></aspect>";

	private static final String INVALID_PDRAO_1_512_1_MISSING_RELATION_OBJECT = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://ww"
			+ "w.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"htt"
			+ "+p://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.512.000000001\"><record><revision ref=\"0\" timestamp="
			+ "\"2014-02-12T09:59:50\" authority=\"pdrUo.001.512.000000001\"/></record><timeDim><timeStm type=\"undefined\"/></timeDim><spatialDim><spatial"
			+ "Stm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.512.000000001\"><relation provider=\"PDR\">aspect_of</rel"
			+ "ation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">NormName_DE</semanticStm></semanticDim><notification><persN"
			+ "ame type=\"forename\" ana=\"pdrPo.001.512.000000001\">Maxi</persName> <persName type=\"surname\" ana=\"pdrPo.001.512.000000001\">Manna</pers"
			+ "Name></notification><validation><validationStm authority=\"pdrUo.001.512.000000001\"><reference quality=\"certain\">pdrRo.001.002.100000001<"
			+ "/reference><interpretation/></validationStm></validation></aspect>";

	private static final String INVALID_ASPECT_1_42_5_DATE_FORMAT = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/200"
			+ "1/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.00000000"
			+ "5\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"undef"
			+ "ined\"/></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relationDim><relationStm subject=\"pdrAo.001.042.000000005\"><relati"
			+ "on object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></relationStm></relationDim><semanticDim><semanticStm provider=\"PDR_"
			+ "2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the order:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" notAfter"
			+ "=\"1713.10.10\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">Krakow</placeName></notification><validation><validati"
			+ "onStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.000000002</reference><interpretation/></validationStm><"
			+ "/validation></aspect>";

	private static final String INVALID_ASPECT_1_42_5_TIME_FORMAT = "<aspect xmlns=\"http://pdr.bbaw.de/namespaces/aodl/\" xmlns:xsi=\"http://www.w3.org/200"
			+ "1/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/aodl/ http://pdr.bbaw.de/schema/aodl.xsd\" id=\"pdrAo.001.042.00000000"
			+ "5\"><record><revision ref=\"0\" timestamp=\"2014-01-14T11:50:15\" authority=\"pdrUo.001.042.000000010\"/></record><timeDim><timeStm type=\"defin"
			+ "ed\"><time accuracy=\"exact\" type=\"when\">1775.01.01</time></timeStm></timeDim><spatialDim><spatialStm type=\"undefined\"/></spatialDim><relat"
			+ "ionDim><relationStm subject=\"pdrAo.001.042.000000005\"><relation object=\"pdrPo.001.042.000000002\" provider=\"PDR\">aspect_of</relation></rela"
			+ "tionStm></relationDim><semanticDim><semanticStm provider=\"PDR_2.0\">biographicalData</semanticStm></semanticDim><notification>Entry in the orde"
			+ "r:<date type=\"event\" ana=\"pdrPo.001.042.000000002\" when=\"1713\">1713</date><placeName type=\"settlement\" ana=\"pdrPo.001.042.000000002\">K"
			+ "rakow</placeName></notification><validation><validationStm authority=\"pdrUo.001.042.000000010\"><reference quality=\"certain\">pdrRo.001.042.00"
			+ "0000002</reference><interpretation/></validationStm></validation></aspect>";

	private static final String VALID_PDRPO_1_42_3 = "<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-ins"
			+ "tance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.042.000000003\"><record><re"
			+ "vision ref=\"0\" timestamp=\"2014-01-21T13:17:26\" authority=\"pdrUo.001.042.000000010\"/></record></person>";

	private static final String VALID_PDRRO_1_42_14 = "<mods xmlns=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi"
			+ ":schemaLocation=\"http://pdr.bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.042.000000014\"><titleInfo><title"
			+ ">Stanisław August Poniatowski</title></titleInfo><name type=\"personal\"><namePart type=\"family\">N</namePart><namePart type=\"given\">N</nameP"
			+ "art><role><roleTerm authority=\"marcrelator\" type=\"code\">aut</roleTerm></role></name><genre authority=\"PDR\">database</genre><originInfo><da"
			+ "teCaptured encoding=\"iso8601\">2014.03.31</dateCaptured></originInfo><location><url>http://en.wikipedia.org/wiki/Stanis%C5%82aw_August_Poniatow"
			+ "ski</url></location><recordInfo><recordCreationDate encoding=\"iso8601\">2014-03-31T10:28:13</recordCreationDate><recordContentSource authority="
			+ "\"PDR\">pdrUo.001.042.000000010</recordContentSource></recordInfo><recordInfo><recordContentSource authority=\"PDR\">pdrUo.001.042.000000010</re"
			+ "cordContentSource><recordChangeDate encoding=\"iso8601\">2014-05-08T14:52:05</recordChangeDate></recordInfo></mods>";

	private static final String VALID_PDRPO_1_42_3_WITH_PODL_NAMESPACE = "<podl:person xmlns:podl=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http:/"
			+ "/www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.0"
			+ "01.042.000000003\"><podl:record><podl:revision ref=\"0\" timestamp=\"2014-01-21T13:17:26\" authority=\"pdrUo.001.042.000000010\"/></podl:record>"
			+ "</podl:person>";

	private static final String VALID_PDRPO_1_43_1 = "<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-ins"
			+ "tance\" xsi:schemaLocation=\"htt"
			+ "p://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.043.000000001\"><record><revision ref=\"0\" timestamp="
			+ "\"2014-01-21T17:18:22\" authority=\"pdrUo.001.043.000000010\"/></record></person>";

	private static final String INVALID_PDRPO_1_43_1_TIMESTAMPLLL = "<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://www.w3.org/200"
			+ "1/XMLSchema-instance\" xsi:schemaLocation=\"htt"
			+ "p://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.043.000000001\"><record><revision ref=\"0\" timestampll"
			+ "l=\"2014-01-21T17:18:22\" authority=\"pdrUo.001.043.000000010\"/></record></person>";

	private static final String INVALID_PDRPO_1_43_1_MISSING_QUALITY_ATTRIBUTE = "<person xmlns=\"http://pdr.bbaw.de/namespaces/podl/\" xmlns:xsi=\"http://w"
			+ "ww.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"htt"
			+ "p://pdr.bbaw.de/namespaces/podl/ http://pdr.bbaw.de/schema/podl.xsd\" id=\"pdrPo.001.043.000000001\"><record><revision ref=\"0\" timestamp="
			+ "\"2014-01-21T17:18:22\" authority=\"pdrUo.001.043.000000010\"/></record><identifiers><identifier provider=\"GND\" authority=\"pdrU0.001.043."
			+ "000000010\"></identifier>123456789X</identifiers></person>";

	private static final String VALID_PDRRO_1_42_14_WITH_MODS_NAMESPACE = "<mods:mods xmlns:mods=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3.or"
			+ "g/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.04"
			+ "2.000000014\"><mods:titleInfo><mods:title>Stanisław August Poniatowski</mods:title></mods:titleInfo><mods:name type=\"personal\"><mods:namePart "
			+ "type=\"family\">N</mods:namePart><mods:namePart type=\"given\">N</mods:namePart><mods:role><mods:roleTerm authority=\"marcrelator\" type=\"code"
			+ "\">aut</mods:roleTerm></mods:role></mods:name><mods:genre authority=\"PDR\">database</mods:genre><mods:originInfo><mods:dateCaptured encoding=\""
			+ "iso8601\">2014.03.31</mods:dateCaptured></mods:originInfo><mods:location><mods:url>http://en.wikipedia.org/wiki/Stanis%C5%82aw_August_Poniatowsk"
			+ "i</mods:url></mods:location><mods:recordInfo><mods:recordCreationDate encoding=\"iso8601\">2014-03-31T10:28:13</mods:recordCreationDate><mods:re"
			+ "cordContentSource authority=\"PDR\">pdrUo.001.042.000000010</mods:recordContentSource></mods:recordInfo><mods:recordInfo><mods:recordContentSour"
			+ "ce authority=\"PDR\">pdrUo.001.042.000000010</mods:recordContentSource><mods:recordChangeDate encoding=\"iso8601\">2014-05-08T14:52:05</mods:rec"
			+ "ordChangeDate></mods:recordInfo></mods:mods>";

	private static final String VALID_PDRRO_1_42_14_WITH_XML_DECLARATION = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><mods xmlns=\"http://www.loc.gov/mods/"
			+ "v3\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/"
			+ "rodl_mods.xsd\" ID=\"pdrRo.001.042.000000014\"><titleInfo><title>Stanisław August Poniatowski</title></titleInfo><name type=\"personal\"><namePa"
			+ "rt type=\"family\">N</namePart><namePart type=\"given\">N</namePart><role><roleTerm authority=\"marcrelator\" type=\"code\">aut</roleTerm></role"
			+ "></name><genre authority=\"PDR\">database</genre><originInfo><dateCaptured encoding=\"iso8601\">2014.03.31</dateCaptured></originInfo><location>"
			+ "<url>http://en.wikipedia.org/wiki/Stanis%C5%82aw_August_Poniatowski</url></location><recordInfo><recordCreationDate encoding=\"iso8601\">2014-03"
			+ "-31T10:28:13</recordCreationDate><recordContentSource authority=\"PDR\">pdrUo.001.042.000000010</recordContentSource></recordInfo><recordInfo><r"
			+ "ecordContentSource authority=\"PDR\">pdrUo.001.042.000000010</recordContentSource><recordChangeDate encoding=\"iso8601\">2014-05-08T14:52:05</re"
			+ "cordChangeDate></recordInfo></mods>";

	private static final String VALID_PDRRO_1_42_14_WITH_XML_DECLARATION_AND_MODS_NAMESPACE = "<?xml version=\"1.0\" encoding=\"UTF-8\"?><mods:mods xmlns:mod"
			+ "s=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http://pdr.bbaw.de/namespaces/rodl"
			+ "/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.042.000000014\"><mods:titleInfo><mods:title>Stanisław August Poniatowski</mods:title>"
			+ "</mods:titleInfo><mods:name type=\"personal\"><mods:namePart type=\"family\">N</mods:namePart><mods:namePart type=\"given\">N</mods:namePart><mo"
			+ "ds:role><mods:roleTerm authority=\"marcrelator\" type=\"code\">aut</mods:roleTerm></mods:role></mods:name><mods:genre authority=\"PDR\">database"
			+ "</mods:genre><mods:originInfo><mods:dateCaptured encoding=\"iso8601\">2014.03.31</mods:dateCaptured></mods:originInfo><mods:location><mods:url>h"
			+ "ttp://en.wikipedia.org/wiki/Stanis%C5%82aw_August_Poniatowski</mods:url></mods:location><mods:recordInfo><mods:recordCreationDate encoding=\"iso"
			+ "8601\">2014-03-31T10:28:13</mods:recordCreationDate><mods:recordContentSource authority=\"PDR\">pdrUo.001.042.000000010</mods:recordContentSourc"
			+ "e></mods:recordInfo><mods:recordInfo><mods:recordContentSource authority=\"PDR\">pdrUo.001.042.000000010</mods:recordContentSource><mods:recordC"
			+ "hangeDate encoding=\"iso8601\">2014-05-08T14:52:05</mods:recordChangeDate></mods:recordInfo></mods:mods>";

	private static final String VALID_PDRRO_1_43_1 = "<mods xmlns=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchema-instance\" xsi"
			+ ":schemaLocation=\"http://pdr."
			+ "bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.043.000000001\"><titleInfo><title/></titleInfo><name><name"
			+ "Part type=\"family\">Toepell</namePart><namePart type=\"given\">Michael</namePart><role><roleTerm>aut</roleTerm></role></name><genre authori"
			+ "ty=\"PDR\">book</genre><originInfo><dateCreated encoding=\"iso8601\">0000</dateCreated></originInfo><identifier type=\"ISBN-10\"/><location/"
			+ "><recordInfo><recordCreationDate encoding=\"iso8601\">2014-01-21T17:18:52</recordCreationDate><recordContentSource authority=\"PDR\">pdrUo.0"
			+ "01.043.000000010</recordContentSource></recordInfo></mods>";

	private static final String INVALID_PDRRO_1_43_1_CREATION_DATE = "<mods xmlns=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3.org/2001/XMLSchem"
			+ "a-instance\" xsi:schemaLocation=\"http://pdr."
			+ "bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.043.000000001\"><titleInfo><title/></titleInfo><name><name"
			+ "Part type=\"family\">Toepell</namePart><namePart type=\"given\">Michael</namePart><role><roleTerm>aut</roleTerm></role></name><genre authori"
			+ "ty=\"PDR\">book</genre><originInfo><dateCreated encoding=\"iso8601\">0000</dateCreated></originInfo><identifier type=\"ISBN-10\"/><location/"
			+ "><recordInfo><recordCreationDate encoding=\"iso8601\">2014-01-21T17:18:XX</recordCreationDate><recordContentSource authority=\"PDR\">pdrUo.0"
			+ "01.043.000000010</recordContentSource></recordInfo></mods>";

	private static final String INVALID_PDRRO_1_789_1_MISSING_RECORD_CONTENT_SOURCE = "<mods xmlns=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3."
			+ "org/2001/XMLSchema-instance\" xsi:schemaLocation=\"http"
			+ "://pdr.bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.789.000000001\"><titleInfo><title>sdfg</title></tit"
			+ "leInfo><name><namePart type=\"family\">sdfg</namePart><namePart type=\"given\">sdfg</namePart><role><roleTerm>aut</roleTerm></role></name><g"
			+ "enre authority=\"PDR\">book</genre><originInfo><dateCreated encoding=\"iso8601\">0000</dateCreated></originInfo><identifier type=\"ISBN-10\""
			+ "/><location/><recordInfo><recordCreationDate encoding=\"iso8601\">2014-01-13T16:14:15</recordCreationDate><recordContentSource authority=\"P"
			+ "DR\">pdrUo.001.789.000000010</recordContentSource></recordInfo><recordInfo><recordChangeDate encoding=\"iso8601\">2014-01-14T16:14:15</recor"
			+ "dChangeDate></recordInfo></mods>";

	private static final String INVALID_PDRRO_1_789_1_EMPTY_RECORD_INFO = "<mods xmlns=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3.org/2001/XML"
			+ "Schema-instance\" xsi:schemaLocation=\"http"
			+ "://pdr.bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.789.000000001\"><titleInfo><title>sdfg</title></tit"
			+ "leInfo><name><namePart type=\"family\">sdfg</namePart><namePart type=\"given\">sdfg</namePart><role><roleTerm>aut</roleTerm></role></name><g"
			+ "enre authority=\"PDR\">book</genre><originInfo><dateCreated encoding=\"iso8601\">0000</dateCreated></originInfo><identifier type=\"ISBN-10\""
			+ "/><location/><recordInfo></recordInfo><recordInfo><recordContentSource authority=\"\">pdrUo.001.789.000000010</reco"
			+ "rdContentSource><recordChangeDate encoding=\"iso8601\">2014-01-14T16:14:15</recordChangeDate></recordInfo></mods>";

	private static final String INVALID_PDRRO_1_798_1_MISSING_NAME_PARTS = "<mods xmlns=\"http://www.loc.gov/mods/v3\" xmlns:xsi=\"http://www.w3.org/2001/XM"
			+ "LSchema-instance\" xsi:schemaLocation=\"http"
			+ "://pdr.bbaw.de/namespaces/rodl/ http://pdr.bbaw.de/schema/rodl_mods.xsd\" ID=\"pdrRo.001.789.000000001\"><titleInfo><title>sdfg</title></tit"
			+ "leInfo><name><role><roleTerm>aut</roleTerm></role></name><g"
			+ "enre authority=\"PDR\">book</genre><originInfo><dateCreated encoding=\"iso8601\">0000</dateCreated></originInfo><identifier type=\"ISBN-10\""
			+ "/><location/><recordInfo><recordCreationDate encoding=\"iso8601\">2014-01-13T16:14:15</recordCreationDate><recordContentSource authority=\"P"
			+ "DR\">pdrUo.001.789.000000010</recordContentSource></recordInfo><recordInfo><recordContentSource authority=\"\">pdrUo.001.789.000000010</reco"
			+ "rdContentSource><recordChangeDate encoding=\"iso8601\">2014-01-14T16:14:15</recordChangeDate></recordInfo></mods>";

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspect1() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRAO_1_43_4);
		assertEquals(VALID_PDRAO_1_43_4, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspect2() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRAO_1_512_1);
		assertEquals(VALID_PDRAO_1_512_1, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithDateY() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_DATE_Y);
		assertEquals(VALID_ASPECT_1_42_5_WITH_DATE_Y, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithDateYM() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_DATE_YM);
		assertEquals(VALID_ASPECT_1_42_5_WITH_DATE_YM, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithDateYMD() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_DATE_YMD);
		assertEquals(VALID_ASPECT_1_42_5_WITH_DATE_YMD, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithDateYMDHM() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_DATE_YMDHM);
		assertEquals(VALID_ASPECT_1_42_5_WITH_DATE_YMDHM, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithDateYMDHMS() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_DATE_YMDHMS);
		assertEquals(VALID_ASPECT_1_42_5_WITH_DATE_YMDHMS, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateValidAspectWithTimeY() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_TIME_Y);
		assertEquals(VALID_ASPECT_1_42_5_WITH_TIME_Y, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithTimeYM() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_TIME_YM);
		assertEquals(VALID_ASPECT_1_42_5_WITH_TIME_YM, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithTimeYMD() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_TIME_YMD);
		assertEquals(VALID_ASPECT_1_42_5_WITH_TIME_YMD, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithTimeYMDHM() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_TIME_YMDHM);
		assertEquals(VALID_ASPECT_1_42_5_WITH_TIME_YMDHM, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateAspectWithTimeYMDHMS() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_ASPECT_1_42_5_WITH_TIME_YMDHMS);
		assertEquals(VALID_ASPECT_1_42_5_WITH_TIME_YMDHMS, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateAspectWithMispelledRootElement() throws Exception
	{
		new PDRObject(INVALID_PDRAO_1_512_1_ASPEKT);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateAspectWithEmptyReference() throws Exception
	{
		new PDRObject(INVALID_PDRAO_1_512_1_EMPTY_REFERENCE);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateAspectWithMissingAuthorityAttribute() throws Exception
	{
		new PDRObject(INVALID_PDRAO_1_512_1_MISSING_AUTHORITY_ATTRIBUTE);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateAspectWithMissingRelationObject() throws Exception
	{
		new PDRObject(INVALID_PDRAO_1_512_1_MISSING_RELATION_OBJECT);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateAspectWithInvalidDateElement() throws Exception
	{
		new PDRObject(INVALID_ASPECT_1_42_5_DATE_FORMAT);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateAspectWithInvalidTimeElement() throws Exception
	{
		new PDRObject(INVALID_ASPECT_1_42_5_TIME_FORMAT);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiatePerson1() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRPO_1_42_3);
		assertEquals(VALID_PDRPO_1_42_3, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiatePerson2() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRPO_1_43_1);
		assertEquals(VALID_PDRPO_1_43_1, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiatePersonWithModsNamespace() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRPO_1_42_3_WITH_PODL_NAMESPACE);
		assertEquals(VALID_PDRPO_1_42_3, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiatePersonWithMispelledElement() throws Exception
	{
		new PDRObject(INVALID_PDRPO_1_43_1_TIMESTAMPLLL);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiatePersonWithMissingQualityAttribute() throws Exception
	{
		new PDRObject(INVALID_PDRPO_1_43_1_MISSING_QUALITY_ATTRIBUTE);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateReference1() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRRO_1_42_14);
		assertEquals(VALID_PDRRO_1_42_14, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateReference2() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRRO_1_43_1);
		assertEquals(VALID_PDRRO_1_43_1, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateReferenceWithModsNamespace() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRRO_1_42_14_WITH_MODS_NAMESPACE);
		assertEquals(VALID_PDRRO_1_42_14, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateReferenceWithXMLDeclaration() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRRO_1_42_14_WITH_XML_DECLARATION);
		assertEquals(VALID_PDRRO_1_42_14, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testInstantiateReferenceWithXMLDeclarationAndModsNamespace() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRRO_1_42_14_WITH_XML_DECLARATION_AND_MODS_NAMESPACE);
		assertEquals(VALID_PDRRO_1_42_14, pdrObject.getXMLContent());
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateReferenceWithInvalidCreationDateFormat() throws Exception
	{
		new PDRObject(INVALID_PDRRO_1_43_1_CREATION_DATE);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateReferenceWithMissingRecordContentSource() throws Exception
	{
		new PDRObject(INVALID_PDRRO_1_789_1_MISSING_RECORD_CONTENT_SOURCE);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateReferenceWithEmptyRecordInfo() throws Exception
	{
		new PDRObject(INVALID_PDRRO_1_789_1_EMPTY_RECORD_INFO);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testInstantiateReferenceWithMissingNameParts() throws Exception
	{
		new PDRObject(INVALID_PDRRO_1_798_1_MISSING_NAME_PARTS);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testRevisionTimestampsFromAspect() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRAO_1_43_4);

		List<Date> revisionTimestamps = pdrObject.getRevisionTimestamps();

		String expectedListString = "[Tue Jan 21 17:21:23 CET 2014]";
		String actualListString = revisionTimestamps.toString();
		assertEquals(expectedListString, actualListString);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testRevisionTimestampsFromPerson() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRPO_1_42_3);

		List<Date> revisionTimestamps = pdrObject.getRevisionTimestamps();

		String expectedListString = "[Tue Jan 21 13:17:26 CET 2014]";
		String actualListString = revisionTimestamps.toString();
		assertEquals(expectedListString, actualListString);
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testRevisionTimestampsFromReference() throws Exception
	{
		PDRObject pdrObject = new PDRObject(VALID_PDRRO_1_42_14);

		List<Date> revisionTimestamps = pdrObject.getRevisionTimestamps();

		String expectedListString = "[Mon Mar 31 10:28:13 CEST 2014, Thu May 08 14:52:05 CEST 2014]";
		String actualListString = revisionTimestamps.toString();
		assertEquals(expectedListString, actualListString);
	}
}
