/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.utils.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.fail;

import java.io.IOException;

import org.bbaw.pdr.padre.PadreCommandException;
import org.bbaw.pdr.solr.SolrCommandException;
import org.bbaw.pdr.utils.RepositoryException;
import org.bbaw.pdr.utils.RepositoryException.ErrorSource;
import org.bbaw.pdr.utils.ValidationException;
import org.junit.Test;

/**
 * @author Fabian Körner
 */
public class TestRepositoryExceptions
{

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = RepositoryException.class)
	public final void testRepositoryExceptionWithMessage() throws Exception
	{
		throw new RepositoryException("testing");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = RepositoryException.class)
	public final void testRepositoryExceptionWithThrowable() throws Exception
	{
		throw new RepositoryException(new IOException("io"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = RepositoryException.class)
	public final void testRepositoryExceptionWithMessageAndThrowable() throws Exception
	{
		throw new RepositoryException("testing", new IOException("io"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testValidationExceptionWithMessage() throws Exception
	{
		throw new ValidationException("testing");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testValidationExceptionWithThrowable() throws Exception
	{
		throw new ValidationException(new IOException("io"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = ValidationException.class)
	public final void testValidationExceptionWithMessageAndThrowable() throws Exception
	{
		throw new ValidationException("testing", new IOException("io"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = SolrCommandException.class)
	public final void testSolrCommandExceptionWithMessage() throws Exception
	{
		throw new SolrCommandException("testing");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = SolrCommandException.class)
	public final void testSolrCommandExceptionWithThrowable() throws Exception
	{
		throw new SolrCommandException(new IOException("io"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = SolrCommandException.class)
	public final void testSolrCommandExceptionWithMessageAndThrowable() throws Exception
	{
		throw new SolrCommandException("testing", new IOException("io"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = PadreCommandException.class)
	public final void testPadreCommandExceptionWithMessage() throws Exception
	{
		throw new PadreCommandException("testing");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = PadreCommandException.class)
	public final void testPadreCommandExceptionWithThrowable() throws Exception
	{
		throw new PadreCommandException(new IOException("io"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = PadreCommandException.class)
	public final void testPadreCommandExceptionWithMessageAndThrowable() throws Exception
	{
		throw new PadreCommandException("testing", new IOException("io"));
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = RepositoryException.class)
	public final void testRepositoryExceptionFromValidationException() throws Exception
	{
		throw new ValidationException("testing");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = RepositoryException.class)
	public final void testRepositoryExceptionFromSolrCommandException() throws Exception
	{
		throw new SolrCommandException("testing");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test (expected = RepositoryException.class)
	public final void testRepositoryExceptionFromPadreCommandException() throws Exception
	{
		throw new PadreCommandException("testing");
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCatchRepositoryException() throws Exception
	{
		try
		{
			TestRepositoryExceptions.throwRepositoryException();
		}
		catch (ValidationException e)
		{
			fail("catched validation exception instead of repository exception");
		}
		catch (RepositoryException e)
		{
			assertEquals("[" + ErrorSource.UNKNOWN.toString() + "]-testing", e.getMessage());
		}
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCatchValidationExceptionBeforeRepositoryException() throws Exception
	{
		try
		{
			TestRepositoryExceptions.throwValidationException();
		}
		catch (ValidationException e)
		{
			assertEquals("[" + ErrorSource.VALIDATION.toString() + "]-testing", e.getMessage());
		}
		catch (RepositoryException e)
		{
			fail("catched repository exception instead of validation exception");
		}
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCatchStorageExceptionBeforeRepositoryException() throws Exception
	{
		try
		{
			TestRepositoryExceptions.throwStorageException();
		}
		catch (PadreCommandException e)
		{
			assertEquals("[" + ErrorSource.STORAGE.toString() + "]-testing", e.getMessage());
		}
		catch (RepositoryException e)
		{
			fail("catched repository exception instead of storage exception");
		}
	}

	/**
	 * @throws Exception Exception.
	 */
	@Test
	public final void testCatchIndexExceptionBeforeRepositoryException() throws Exception
	{
		try
		{
			TestRepositoryExceptions.throwIndexException();
		}
		catch (SolrCommandException e)
		{
			assertEquals("[" + ErrorSource.INDEX.toString() + "]-testing", e.getMessage());
		}
		catch (RepositoryException e)
		{
			fail("catched repository exception instead of index exception");
		}
	}

	private static void throwRepositoryException() throws Exception
	{
		throw new RepositoryException("testing");
	}

	private static void throwValidationException() throws Exception
	{
		throw new ValidationException("testing");
	}

	private static void throwStorageException() throws Exception
	{
		throw new PadreCommandException("testing");
	}

	private static void throwIndexException() throws Exception
	{
		throw new SolrCommandException("testing");
	}

}
