/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * Encapsultes methods for the creation of Apache Solr's time format
 * (<code>yyyy-MM-dd'T'HH:mm:ss'Z'</code>).
 * @author fkoerner
 *
 */
final class SolrCompliantTime
{

	private static final SimpleDateFormat[] HANDLED_FORMATS = {
		new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss"),
		new SimpleDateFormat("yyyy-MM-dd'T'HH:mm"),
		new SimpleDateFormat("yyyy-MM-dd"),
		new SimpleDateFormat("yyyy-MM"),
		new SimpleDateFormat("yyyy"),
	};

	private static final SimpleDateFormat SOLR_COMPLIANT_FORMAT = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss'Z'");

	private SolrCompliantTime()
	{
	}

	protected static String createFromFragment(final String fragment)
	throws SolrCommandException
	{
		String result = "";
		try
		{
			Date date = null;
			int index = 0;
			while (null == date)
			{
				try
				{
					date = HANDLED_FORMATS[index++].parse(fragment);
				}
				catch (ParseException pe)
				{
					continue;
				}
			}
			result = SOLR_COMPLIANT_FORMAT.format(date);
		}
		catch (ArrayIndexOutOfBoundsException aie)
		{
			throw new SolrCommandException("time fragment of unhandled format: " + fragment);
		}
		return result;
	}
}
