/*
 *	Copyright 2012-2014 Berlin-Brandenburgische Akademie der Wissenschaften
 *
 *	This file is part of PDR-LIB.
 *
 *	PDR-LIB is free software: you can redistribute it and/or modify it under
 *	the terms of the GNU Lesser General Public License as published by the
 *	Free Software Foundation, either version 3 of the License, or (at your
 *	option) any later version.
 *
 *	PDR-LIB is distributed in the hope that it will be useful, but WITHOUT ANY
 *	WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 *	FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 *	more details.
 *
 *	You should have received a copy of the GNU Lesser General Public License
 *	along with PDR-LIB.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.bbaw.pdr.solr;

import java.util.Iterator;

import javax.xml.namespace.QName;

import org.apache.axiom.om.OMElement;

/**
 * Solr input document with index fields specific to references.
 * @author Fabian Körner
 */
public class SolrInputReference extends SolrInputCommon
{

	private static final long serialVersionUID = 2951030731343601498L;

	private QName _qNameTitleInfoElement;
	private QName _qNameTitleElement;
	private QName _qNameNameElement;
	private QName _qNameNamePartElement;

	protected SolrInputReference(final OMElement root)
	{
		super(root);
		this.initQNames();
		this.addSpecificIndexFields();
	}

	private void initQNames()
	{
		_qNameTitleInfoElement = super.createQNameOfElement("titleInfo");
		_qNameTitleElement = super.createQNameOfElement("title");
		_qNameNameElement = super.createQNameOfElement("name");
		_qNameNamePartElement = super.createQNameOfElement("namePart");
	}

	private void addSpecificIndexFields()
	{
		OMElement titleInfoElement = super.getRoot().getFirstChildWithName(_qNameTitleInfoElement);
		OMElement titleElement = titleInfoElement.getFirstChildWithName(_qNameTitleElement);

		addField("reference.title", titleElement.getText());

		Iterator<?> names = super.getRoot().getChildrenWithName(_qNameNameElement);
		OMElement name;
		OMElement namePart;
		while (names.hasNext())
		{
			name = (OMElement) names.next();
			Iterator<?> nameParts = name.getChildrenWithName(_qNameNamePartElement);
			while (nameParts.hasNext())
			{
				namePart = (OMElement) nameParts.next();
				addField("reference.name", namePart.getText());
			}
		}
	}
}
